.. include:: globals.rst

.. _api:

API
===

.. contents::
    :local:

IntegerVersionField
-------------------
.. autoclass:: concurrency.fields.IntegerVersionField


AutoIncVersionField
-------------------
.. autoclass:: concurrency.fields.AutoIncVersionField

RandomVersionField
------------------
.. autoclass:: concurrency.fields.RandomVersionField


VersionField
------------
.. autoclass:: concurrency.forms.VersionField


ConcurrentForm
--------------
.. autoclass:: concurrency.forms.ConcurrentForm


VersionWidget
-------------
.. autoclass:: concurrency.forms.VersionWidget


.. _RecordModifiedError:

RecordModifiedError
-------------------
.. autoclass:: concurrency.core.RecordModifiedError


